@@ -18,6 +18,12 @@ local lfs = require "lfs"
 local tostring, tonumber, pairs, ipairs, error, type, pcall, xpcall, setmetatable, dofile, rawget, rawset, assert, loadfile =
   tostring, tonumber, pairs, ipairs, error, type, pcall, xpcall, setmetatable, dofile, rawget, rawset, assert, loadfile
 
+if _VERSION < "Lua 5.2" then
+	local coxpcall = require "coxpcall"
+	pcall = coxpcall.pcall
+	xpcall = coxpcall.xpcall
+end
+
 local package = package
 
 local _, ringer = pcall(require, "wsapi.ringer")
@@ -385,7 +391,7 @@ end
 -- for the previous example
 function _M.adjust_non_wrapped(wsapi_env, filename, launcher)
   if filename == "" or not_compatible(wsapi_env, filename) or
-    (launcher and filename:match(launcher:gsub("%.", "%.") .. "$")) then
+    (launcher and filename:match(launcher:gsub("%.", ".") .. "$")) then
     local path_info = wsapi_env.PATH_INFO
     local docroot = wsapi_env.DOCUMENT_ROOT
     if docroot:sub(#docroot) ~= "/" and docroot:sub(#docroot) ~= "\\" then
